@@ -106,7 +106,9 @@ def main():
     grid.fit(X_train, y_train.values.ravel())
     print("Best estimator:\n{}".format(grid.best_estimator_))
     # print("model score: %.3f" % lin.score(X_train, y_train))
-    feature_importances = grid.best_estimator_.feature_importances_
+    rf_fit = grid.fit(X_train, y_train.values.ravel())
+    feature_importances = rf_fit.best_estimator_._final_estimator.feature_importances_
+    # feature_importances = grid.best_estimator_.feature_importances_
     print(feature_importances)
 
     final_model = grid.best_estimator_
